Documentation
¶
Overview ¶
Package v1alpha1 contains API Schema definitions for the package v1alpha1 API group +kubebuilder:object:generate=true +groupName=multiarch.builder.io
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // GroupVersion is group version used to register these objects GroupVersion = schema.GroupVersion{Group: "multiarch.builder.io", Version: "v1alpha1"} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type Build ¶
type Build struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
// spec holds all the input necessary to produce a new package, and the conditions when
// to trigger them.
Spec BuildSpec `json:"spec,omitempty"`
// status holds any relevant information about a build config
// +optional
Status BuildStatus `json:"status,omitempty"`
}
Build is the Schema for the package builds API +k8s:openapi-gen=true +kubebuilder:subresource:status +kubebuilder:resource:path=builds,scope=Namespaced
func (*Build) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Build.
func (*Build) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Build) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*Build) InstallStatus ¶
func (s *Build) InstallStatus() InstallStatus
InstallStatus retrieves the status of a Build CR
type BuildList ¶
type BuildList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Build `json:"items"`
}
BuildList contains a list of a build
func (*BuildList) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new BuildList.
func (*BuildList) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*BuildList) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type BuildSpec ¶
type BuildSpec struct {
// ImageStream stores the stream where to push the built image
ImageStream string `json:"imagestream,omitempty"`
// Environment stores the spack.yaml env configuration file
Environment []SpackEnvionment `json:"environment,omitempty"`
}
BuildSpec defines the desired state of a package +k8s:openapi-gen=true
func (*BuildSpec) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new BuildSpec.
func (*BuildSpec) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type BuildStatus ¶
type BuildStatus struct {
State InstallStatus `json:"state,omitempty"`
LastUpdate metav1.Time `json:"lastUpdate,omitempty"`
Reason string `json:"reason,omitempty"`
}
BuildStatus defines the observed state of a build +k8s:openapi-gen=true
func (*BuildStatus) DeepCopy ¶
func (in *BuildStatus) DeepCopy() *BuildStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new BuildStatus.
func (*BuildStatus) DeepCopyInto ¶
func (in *BuildStatus) DeepCopyInto(out *BuildStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type InstallStatus ¶
type InstallStatus string
InstallStatus describes the state of installation of a package
const ( // EmptyStatus indicates that the package build have not even been // validated EmptyStatus InstallStatus = "empty" // ValidatedPackage indicates that the package build have been // validated ValidatedPackage InstallStatus = "validated" // ErroredPackage indicates that the package build status is // failing ErroredPackage InstallStatus = "error" // InitializedStatus indicates that the package build have been // triggered InitializedStatus InstallStatus = "initialized" // UpdatedStatus indicates that the package build have been // updated UpdatedStatus InstallStatus = "updated" // DeletedStatus indicates that the package build have been // created DeletedStatus InstallStatus = "deleted" )
type SpackEnvionment ¶
type SpackEnvionment struct {
// Name of the Spack Environment profile to be used in buildConfig.
Name *string `json:"name"`
// Specification of the Spack Environment to be consumed by the Spack builder.
Data *string `json:"data"`
}
SpackEnvionment holds the definition of a Spack Environment.
func (*SpackEnvionment) DeepCopy ¶
func (in *SpackEnvionment) DeepCopy() *SpackEnvionment
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SpackEnvionment.
func (*SpackEnvionment) DeepCopyInto ¶
func (in *SpackEnvionment) DeepCopyInto(out *SpackEnvionment)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.